@@ -25,14 +25,19 @@
 void
 gsh_widget_set_font(GtkWidget *widget, const gchar *font)
 {
-	PangoFontDescription *font_desc;
-
 	ARPASSERT(widget);
 	ARPASSERT(font);
 
-	font_desc = pango_font_description_from_string(font);
-	gtk_widget_modify_font(widget, font_desc);
-	pango_font_description_free(font_desc);
+	if(VTE_IS_TERMINAL(widget))
+		vte_terminal_set_font_from_string(VTE_TERMINAL(widget), font);
+	else
+	{
+		PangoFontDescription *font_desc;
+	
+		font_desc = pango_font_description_from_string(font);
+		gtk_widget_modify_font(widget, font_desc);
+		pango_font_description_free(font_desc);
+	}
 }
 
 void
