@@ -22,6 +22,10 @@
 
 #include "gtkshell.h"
 
+extern FILE *yyin, *yyout;
+extern int gsh_parsed_argc;
+extern char ** gsh_parsed_argv;
+
 #ifdef _GNU_SOURCE
 inline
 #endif				/* _GNU_SOURCE */
@@ -45,9 +49,23 @@ gsh_handle_switch_arguments(struct GSH * gsh, int argc,
 	case 'd':
 		gsh_handle_dialog_arguments(gsh, argc, argv, counter);
 		break;
+	case 'f':
+		gsh_count(argc, counter);
+		yyin=fopen(argv[*counter], "r");
+		gsh_append_arg((char*)"guidl");
+		yyparse();
+		gsh_parse_arguments(gsh, gsh_parsed_argc, gsh_parsed_argv);
+		//gsh_free_parse_memory();
+		break;
 	case 'o':
 		gsh_handle_option_arguments(gsh, argc, argv, counter);
 		break;
+	case 'p': /* Handle piped in GUIDL input.  */
+		gsh_append_arg((char*)"guidl");
+		yyparse();
+		gsh_parse_arguments(gsh, gsh_parsed_argc, gsh_parsed_argv);
+		//gsh_free_parse_memory();
+		break;
 	default:
 		g_warning("%s:  %s undefined\n", argv[0], argv[(*counter)]);
 	}
